"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from apideck.api_client import ApiClient, Endpoint as _Endpoint
from apideck.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from apideck.model.applicant import Applicant
from apideck.model.applicants_filter import ApplicantsFilter
from apideck.model.application import Application
from apideck.model.bad_request_response import BadRequestResponse
from apideck.model.create_applicant_response import CreateApplicantResponse
from apideck.model.create_application_response import CreateApplicationResponse
from apideck.model.delete_applicant_response import DeleteApplicantResponse
from apideck.model.delete_application_response import DeleteApplicationResponse
from apideck.model.get_applicant_response import GetApplicantResponse
from apideck.model.get_applicants_response import GetApplicantsResponse
from apideck.model.get_application_response import GetApplicationResponse
from apideck.model.get_applications_response import GetApplicationsResponse
from apideck.model.get_job_response import GetJobResponse
from apideck.model.get_jobs_response import GetJobsResponse
from apideck.model.not_found_response import NotFoundResponse
from apideck.model.pass_through_query import PassThroughQuery
from apideck.model.payment_required_response import PaymentRequiredResponse
from apideck.model.unauthorized_response import UnauthorizedResponse
from apideck.model.unexpected_error_response import UnexpectedErrorResponse
from apideck.model.unprocessable_response import UnprocessableResponse
from apideck.model.update_applicant_response import UpdateApplicantResponse
from apideck.model.update_application_response import UpdateApplicationResponse


class AtsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.applicants_add_endpoint = _Endpoint(
            settings={
                'response_type': (CreateApplicantResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applicants',
                'operation_id': 'applicants_add',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'applicant',
                    'raw',
                    'consumer_id',
                    'app_id',
                    'service_id',
                ],
                'required': [
                    'applicant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'applicant':
                        (Applicant,),
                    'raw':
                        (bool,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                },
                'attribute_map': {
                    'raw': 'raw',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                },
                'location_map': {
                    'applicant': 'body',
                    'raw': 'query',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.applicants_all_endpoint = _Endpoint(
            settings={
                'response_type': (GetApplicantsResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applicants',
                'operation_id': 'applicants_all',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'raw',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'cursor',
                    'limit',
                    'filter',
                    'pass_through',
                    'fields',
                ],
                'required': [],
                'nullable': [
                    'cursor',
                    'fields',
                ],
                'enum': [
                ],
                'validation': [
                    'limit',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 200,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'raw':
                        (bool,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'cursor':
                        (str, none_type,),
                    'limit':
                        (int,),
                    'filter':
                        (ApplicantsFilter,),
                    'pass_through':
                        (PassThroughQuery,),
                    'fields':
                        (str, none_type,),
                },
                'attribute_map': {
                    'raw': 'raw',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'cursor': 'cursor',
                    'limit': 'limit',
                    'filter': 'filter',
                    'pass_through': 'pass_through',
                    'fields': 'fields',
                },
                'location_map': {
                    'raw': 'query',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'cursor': 'query',
                    'limit': 'query',
                    'filter': 'query',
                    'pass_through': 'query',
                    'fields': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.applicants_delete_endpoint = _Endpoint(
            settings={
                'response_type': (DeleteApplicantResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applicants/{id}',
                'operation_id': 'applicants_delete',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'raw',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'raw':
                        (bool,),
                },
                'attribute_map': {
                    'id': 'id',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'raw': 'raw',
                },
                'location_map': {
                    'id': 'path',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'raw': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.applicants_one_endpoint = _Endpoint(
            settings={
                'response_type': (GetApplicantResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applicants/{id}',
                'operation_id': 'applicants_one',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'raw',
                    'fields',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                    'fields',
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'raw':
                        (bool,),
                    'fields':
                        (str, none_type,),
                },
                'attribute_map': {
                    'id': 'id',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'raw': 'raw',
                    'fields': 'fields',
                },
                'location_map': {
                    'id': 'path',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'raw': 'query',
                    'fields': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.applicants_update_endpoint = _Endpoint(
            settings={
                'response_type': (UpdateApplicantResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applicants/{id}',
                'operation_id': 'applicants_update',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'applicant',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'raw',
                ],
                'required': [
                    'id',
                    'applicant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'applicant':
                        (Applicant,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'raw':
                        (bool,),
                },
                'attribute_map': {
                    'id': 'id',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'raw': 'raw',
                },
                'location_map': {
                    'id': 'path',
                    'applicant': 'body',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'raw': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.applications_add_endpoint = _Endpoint(
            settings={
                'response_type': (CreateApplicationResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applications',
                'operation_id': 'applications_add',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'application',
                    'raw',
                    'consumer_id',
                    'app_id',
                    'service_id',
                ],
                'required': [
                    'application',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'application':
                        (Application,),
                    'raw':
                        (bool,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                },
                'attribute_map': {
                    'raw': 'raw',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                },
                'location_map': {
                    'application': 'body',
                    'raw': 'query',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.applications_all_endpoint = _Endpoint(
            settings={
                'response_type': (GetApplicationsResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applications',
                'operation_id': 'applications_all',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'raw',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'cursor',
                    'pass_through',
                    'limit',
                ],
                'required': [],
                'nullable': [
                    'cursor',
                ],
                'enum': [
                ],
                'validation': [
                    'limit',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 200,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'raw':
                        (bool,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'cursor':
                        (str, none_type,),
                    'pass_through':
                        (PassThroughQuery,),
                    'limit':
                        (int,),
                },
                'attribute_map': {
                    'raw': 'raw',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'cursor': 'cursor',
                    'pass_through': 'pass_through',
                    'limit': 'limit',
                },
                'location_map': {
                    'raw': 'query',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'cursor': 'query',
                    'pass_through': 'query',
                    'limit': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.applications_delete_endpoint = _Endpoint(
            settings={
                'response_type': (DeleteApplicationResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applications/{id}',
                'operation_id': 'applications_delete',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'raw',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'raw':
                        (bool,),
                },
                'attribute_map': {
                    'id': 'id',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'raw': 'raw',
                },
                'location_map': {
                    'id': 'path',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'raw': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.applications_one_endpoint = _Endpoint(
            settings={
                'response_type': (GetApplicationResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applications/{id}',
                'operation_id': 'applications_one',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'raw',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'raw':
                        (bool,),
                },
                'attribute_map': {
                    'id': 'id',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'raw': 'raw',
                },
                'location_map': {
                    'id': 'path',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'raw': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.applications_update_endpoint = _Endpoint(
            settings={
                'response_type': (UpdateApplicationResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/applications/{id}',
                'operation_id': 'applications_update',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'application',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'raw',
                ],
                'required': [
                    'id',
                    'application',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'application':
                        (Application,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'raw':
                        (bool,),
                },
                'attribute_map': {
                    'id': 'id',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'raw': 'raw',
                },
                'location_map': {
                    'id': 'path',
                    'application': 'body',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'raw': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.jobs_all_endpoint = _Endpoint(
            settings={
                'response_type': (GetJobsResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/jobs',
                'operation_id': 'jobs_all',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'raw',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'cursor',
                    'limit',
                    'pass_through',
                    'fields',
                ],
                'required': [],
                'nullable': [
                    'cursor',
                    'fields',
                ],
                'enum': [
                ],
                'validation': [
                    'limit',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 200,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'raw':
                        (bool,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'cursor':
                        (str, none_type,),
                    'limit':
                        (int,),
                    'pass_through':
                        (PassThroughQuery,),
                    'fields':
                        (str, none_type,),
                },
                'attribute_map': {
                    'raw': 'raw',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'cursor': 'cursor',
                    'limit': 'limit',
                    'pass_through': 'pass_through',
                    'fields': 'fields',
                },
                'location_map': {
                    'raw': 'query',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'cursor': 'query',
                    'limit': 'query',
                    'pass_through': 'query',
                    'fields': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.jobs_one_endpoint = _Endpoint(
            settings={
                'response_type': (GetJobResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/ats/jobs/{id}',
                'operation_id': 'jobs_one',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'consumer_id',
                    'app_id',
                    'service_id',
                    'raw',
                    'fields',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                    'fields',
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'consumer_id':
                        (str,),
                    'app_id':
                        (str,),
                    'service_id':
                        (str,),
                    'raw':
                        (bool,),
                    'fields':
                        (str, none_type,),
                },
                'attribute_map': {
                    'id': 'id',
                    'consumer_id': 'x-apideck-consumer-id',
                    'app_id': 'x-apideck-app-id',
                    'service_id': 'x-apideck-service-id',
                    'raw': 'raw',
                    'fields': 'fields',
                },
                'location_map': {
                    'id': 'path',
                    'consumer_id': 'header',
                    'app_id': 'header',
                    'service_id': 'header',
                    'raw': 'query',
                    'fields': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def applicants_add(
        self,
        applicant,
        **kwargs
    ):
        """Create Applicant  # noqa: E501

        Create Applicant  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applicants_add(applicant, async_req=True)
        >>> result = thread.get()

        Args:
            applicant (Applicant):

        Keyword Args:
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CreateApplicantResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['applicant'] = \
            applicant
        return self.applicants_add_endpoint.call_with_http_info(**kwargs)

    def applicants_all(
        self,
        **kwargs
    ):
        """List Applicants  # noqa: E501

        List Applicants  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applicants_all(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            cursor (str, none_type): Cursor to start from. You can find cursors for next/previous pages in the meta.cursors property of the response.. [optional]
            limit (int): Number of results to return. Minimum 1, Maximum 200, Default 20. [optional] if omitted the server will use the default value of 20
            filter (ApplicantsFilter): Apply filters. [optional]
            pass_through (PassThroughQuery): Optional unmapped key/values that will be passed through to downstream as query parameters. Ie: ?pass_through[search]=leads becomes ?search=leads. [optional]
            fields (str, none_type): The 'fields' parameter allows API users to specify the fields they want to include in the API response. If this parameter is not present, the API will return all available fields. If this parameter is present, only the fields specified in the comma-separated string will be included in the response. Nested properties can also be requested by using a dot notation. <br /><br />Example: `fields=name,email,addresses.city`<br /><br />In the example above, the response will only include the fields \"name\", \"email\" and \"addresses.city\". If any other fields are available, they will be excluded.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetApplicantsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.applicants_all_endpoint.call_with_http_info(**kwargs)

    def applicants_delete(
        self,
        id,
        **kwargs
    ):
        """Delete Applicant  # noqa: E501

        Delete Applicant  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applicants_delete(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of the record you are acting upon.

        Keyword Args:
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DeleteApplicantResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.applicants_delete_endpoint.call_with_http_info(**kwargs)

    def applicants_one(
        self,
        id,
        **kwargs
    ):
        """Get Applicant  # noqa: E501

        Get Applicant  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applicants_one(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of the record you are acting upon.

        Keyword Args:
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            fields (str, none_type): The 'fields' parameter allows API users to specify the fields they want to include in the API response. If this parameter is not present, the API will return all available fields. If this parameter is present, only the fields specified in the comma-separated string will be included in the response. Nested properties can also be requested by using a dot notation. <br /><br />Example: `fields=name,email,addresses.city`<br /><br />In the example above, the response will only include the fields \"name\", \"email\" and \"addresses.city\". If any other fields are available, they will be excluded.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetApplicantResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.applicants_one_endpoint.call_with_http_info(**kwargs)

    def applicants_update(
        self,
        id,
        applicant,
        **kwargs
    ):
        """Update Applicant  # noqa: E501

        Update Applicant  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applicants_update(id, applicant, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of the record you are acting upon.
            applicant (Applicant):

        Keyword Args:
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            UpdateApplicantResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        kwargs['applicant'] = \
            applicant
        return self.applicants_update_endpoint.call_with_http_info(**kwargs)

    def applications_add(
        self,
        application,
        **kwargs
    ):
        """Create Application  # noqa: E501

        Create Application  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applications_add(application, async_req=True)
        >>> result = thread.get()

        Args:
            application (Application):

        Keyword Args:
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CreateApplicationResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['application'] = \
            application
        return self.applications_add_endpoint.call_with_http_info(**kwargs)

    def applications_all(
        self,
        **kwargs
    ):
        """List Applications  # noqa: E501

        List Applications  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applications_all(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            cursor (str, none_type): Cursor to start from. You can find cursors for next/previous pages in the meta.cursors property of the response.. [optional]
            pass_through (PassThroughQuery): Optional unmapped key/values that will be passed through to downstream as query parameters. Ie: ?pass_through[search]=leads becomes ?search=leads. [optional]
            limit (int): Number of results to return. Minimum 1, Maximum 200, Default 20. [optional] if omitted the server will use the default value of 20
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetApplicationsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.applications_all_endpoint.call_with_http_info(**kwargs)

    def applications_delete(
        self,
        id,
        **kwargs
    ):
        """Delete Application  # noqa: E501

        Delete Application  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applications_delete(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of the record you are acting upon.

        Keyword Args:
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DeleteApplicationResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.applications_delete_endpoint.call_with_http_info(**kwargs)

    def applications_one(
        self,
        id,
        **kwargs
    ):
        """Get Application  # noqa: E501

        Get Application  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applications_one(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of the record you are acting upon.

        Keyword Args:
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetApplicationResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.applications_one_endpoint.call_with_http_info(**kwargs)

    def applications_update(
        self,
        id,
        application,
        **kwargs
    ):
        """Update Application  # noqa: E501

        Update Application  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applications_update(id, application, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of the record you are acting upon.
            application (Application):

        Keyword Args:
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            UpdateApplicationResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        kwargs['application'] = \
            application
        return self.applications_update_endpoint.call_with_http_info(**kwargs)

    def jobs_all(
        self,
        **kwargs
    ):
        """List Jobs  # noqa: E501

        List Jobs  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.jobs_all(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            cursor (str, none_type): Cursor to start from. You can find cursors for next/previous pages in the meta.cursors property of the response.. [optional]
            limit (int): Number of results to return. Minimum 1, Maximum 200, Default 20. [optional] if omitted the server will use the default value of 20
            pass_through (PassThroughQuery): Optional unmapped key/values that will be passed through to downstream as query parameters. Ie: ?pass_through[search]=leads becomes ?search=leads. [optional]
            fields (str, none_type): The 'fields' parameter allows API users to specify the fields they want to include in the API response. If this parameter is not present, the API will return all available fields. If this parameter is present, only the fields specified in the comma-separated string will be included in the response. Nested properties can also be requested by using a dot notation. <br /><br />Example: `fields=name,email,addresses.city`<br /><br />In the example above, the response will only include the fields \"name\", \"email\" and \"addresses.city\". If any other fields are available, they will be excluded.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetJobsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.jobs_all_endpoint.call_with_http_info(**kwargs)

    def jobs_one(
        self,
        id,
        **kwargs
    ):
        """Get Job  # noqa: E501

        Get Job  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.jobs_one(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of the record you are acting upon.

        Keyword Args:
            consumer_id (str): ID of the consumer which you want to get or push data from. [optional]
            app_id (str): The ID of your Unify application. [optional]
            service_id (str): Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.. [optional]
            raw (bool): Include raw response. Mostly used for debugging purposes. [optional] if omitted the server will use the default value of False
            fields (str, none_type): The 'fields' parameter allows API users to specify the fields they want to include in the API response. If this parameter is not present, the API will return all available fields. If this parameter is present, only the fields specified in the comma-separated string will be included in the response. Nested properties can also be requested by using a dot notation. <br /><br />Example: `fields=name,email,addresses.city`<br /><br />In the example above, the response will only include the fields \"name\", \"email\" and \"addresses.city\". If any other fields are available, they will be excluded.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetJobResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.jobs_one_endpoint.call_with_http_info(**kwargs)




"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.connector_doc import ConnectorDoc
from apideck.model.connector_event import ConnectorEvent
from apideck.model.connector_oauth_scopes import ConnectorOauthScopes
from apideck.model.connector_setting import ConnectorSetting
from apideck.model.connector_status import ConnectorStatus
from apideck.model.connector_tls_support import ConnectorTlsSupport
from apideck.model.connector_unified_apis import ConnectorUnifiedApis
from apideck.model.linked_connector_resource import LinkedConnectorResource
from apideck.model.schema_support import SchemaSupport
from apideck.model.webhook_support import WebhookSupport
globals()['ConnectorDoc'] = ConnectorDoc
globals()['ConnectorEvent'] = ConnectorEvent
globals()['ConnectorOauthScopes'] = ConnectorOauthScopes
globals()['ConnectorSetting'] = ConnectorSetting
globals()['ConnectorStatus'] = ConnectorStatus
globals()['ConnectorTlsSupport'] = ConnectorTlsSupport
globals()['ConnectorUnifiedApis'] = ConnectorUnifiedApis
globals()['LinkedConnectorResource'] = LinkedConnectorResource
globals()['SchemaSupport'] = SchemaSupport
globals()['WebhookSupport'] = WebhookSupport
from apideck.model.connector import Connector


class TestConnector(unittest.TestCase):
    """Connector unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConnector(self):
        """Test Connector"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Connector()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.bank_account import BankAccount
from apideck.model.currency import Currency
from apideck.model.ledger_account_categories import LedgerAccountCategories
from apideck.model.ledger_account_parent_account import LedgerAccountParentAccount
from apideck.model.linked_tax_rate import LinkedTaxRate
globals()['BankAccount'] = BankAccount
globals()['Currency'] = Currency
globals()['LedgerAccountCategories'] = LedgerAccountCategories
globals()['LedgerAccountParentAccount'] = LedgerAccountParentAccount
globals()['LinkedTaxRate'] = LinkedTaxRate
from apideck.model.ledger_account import LedgerAccount


class TestLedgerAccount(unittest.TestCase):
    """LedgerAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLedgerAccount(self):
        """Test LedgerAccount"""
        # FIXME: construct object with mandatory attributes with example values
        # model = LedgerAccount()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from apideck.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from apideck.model.accounting_customer import AccountingCustomer
from apideck.model.accounting_event_type import AccountingEventType
from apideck.model.activities_filter import ActivitiesFilter
from apideck.model.activity import Activity
from apideck.model.activity_attendee import ActivityAttendee
from apideck.model.address import Address
from apideck.model.api import Api
from apideck.model.api_resource import ApiResource
from apideck.model.api_resource_coverage import ApiResourceCoverage
from apideck.model.api_resource_coverage_coverage import ApiResourceCoverageCoverage
from apideck.model.api_resource_linked_resources import ApiResourceLinkedResources
from apideck.model.api_resources import ApiResources
from apideck.model.api_status import ApiStatus
from apideck.model.apis_filter import ApisFilter
from apideck.model.applicant import Applicant
from apideck.model.applicant_social_links import ApplicantSocialLinks
from apideck.model.applicant_websites import ApplicantWebsites
from apideck.model.applicants_filter import ApplicantsFilter
from apideck.model.application import Application
from apideck.model.application_stage import ApplicationStage
from apideck.model.assignee import Assignee
from apideck.model.ats_activity import AtsActivity
from apideck.model.ats_event_type import AtsEventType
from apideck.model.auth_type import AuthType
from apideck.model.bad_request_response import BadRequestResponse
from apideck.model.balance_sheet import BalanceSheet
from apideck.model.balance_sheet_assets import BalanceSheetAssets
from apideck.model.balance_sheet_assets_current_assets import BalanceSheetAssetsCurrentAssets
from apideck.model.balance_sheet_assets_current_assets_accounts import BalanceSheetAssetsCurrentAssetsAccounts
from apideck.model.balance_sheet_assets_fixed_assets import BalanceSheetAssetsFixedAssets
from apideck.model.balance_sheet_assets_fixed_assets_accounts import BalanceSheetAssetsFixedAssetsAccounts
from apideck.model.balance_sheet_equity import BalanceSheetEquity
from apideck.model.balance_sheet_equity_items import BalanceSheetEquityItems
from apideck.model.balance_sheet_filter import BalanceSheetFilter
from apideck.model.balance_sheet_liabilities import BalanceSheetLiabilities
from apideck.model.balance_sheet_liabilities_accounts import BalanceSheetLiabilitiesAccounts
from apideck.model.bank_account import BankAccount
from apideck.model.benefit import Benefit
from apideck.model.bill import Bill
from apideck.model.bill_line_item import BillLineItem
from apideck.model.bills_sort import BillsSort
from apideck.model.branch import Branch
from apideck.model.cash_details import CashDetails
from apideck.model.collection import Collection
from apideck.model.collection_tag import CollectionTag
from apideck.model.collection_ticket_comment import CollectionTicketComment
from apideck.model.collection_user import CollectionUser
from apideck.model.collections_sort import CollectionsSort
from apideck.model.comments_sort import CommentsSort
from apideck.model.companies_filter import CompaniesFilter
from apideck.model.companies_sort import CompaniesSort
from apideck.model.company import Company
from apideck.model.company_info import CompanyInfo
from apideck.model.company_row_type import CompanyRowType
from apideck.model.compensation import Compensation
from apideck.model.connection import Connection
from apideck.model.connection_configuration import ConnectionConfiguration
from apideck.model.connection_defaults import ConnectionDefaults
from apideck.model.connection_import_data import ConnectionImportData
from apideck.model.connection_import_data_credentials import ConnectionImportDataCredentials
from apideck.model.connection_metadata import ConnectionMetadata
from apideck.model.connection_state import ConnectionState
from apideck.model.connection_webhook import ConnectionWebhook
from apideck.model.connector import Connector
from apideck.model.connector_doc import ConnectorDoc
from apideck.model.connector_event import ConnectorEvent
from apideck.model.connector_oauth_scopes import ConnectorOauthScopes
from apideck.model.connector_oauth_scopes1 import ConnectorOauthScopes1
from apideck.model.connector_resource import ConnectorResource
from apideck.model.connector_setting import ConnectorSetting
from apideck.model.connector_status import ConnectorStatus
from apideck.model.connector_tls_support import ConnectorTlsSupport
from apideck.model.connector_unified_apis import ConnectorUnifiedApis
from apideck.model.connectors_filter import ConnectorsFilter
from apideck.model.consumer import Consumer
from apideck.model.consumer_connection import ConsumerConnection
from apideck.model.consumer_metadata import ConsumerMetadata
from apideck.model.consumer_request_counts_in_date_range_response import ConsumerRequestCountsInDateRangeResponse
from apideck.model.consumer_request_counts_in_date_range_response_data import ConsumerRequestCountsInDateRangeResponseData
from apideck.model.contact import Contact
from apideck.model.contacts_filter import ContactsFilter
from apideck.model.contacts_sort import ContactsSort
from apideck.model.copy_folder_request import CopyFolderRequest
from apideck.model.country import Country
from apideck.model.create_activity_response import CreateActivityResponse
from apideck.model.create_applicant_response import CreateApplicantResponse
from apideck.model.create_application_response import CreateApplicationResponse
from apideck.model.create_bill_response import CreateBillResponse
from apideck.model.create_comment_response import CreateCommentResponse
from apideck.model.create_company_response import CreateCompanyResponse
from apideck.model.create_connection_response import CreateConnectionResponse
from apideck.model.create_consumer_response import CreateConsumerResponse
from apideck.model.create_contact_response import CreateContactResponse
from apideck.model.create_credit_note_response import CreateCreditNoteResponse
from apideck.model.create_custom_mapping_request import CreateCustomMappingRequest
from apideck.model.create_custom_mapping_response import CreateCustomMappingResponse
from apideck.model.create_customer_response import CreateCustomerResponse
from apideck.model.create_department_response import CreateDepartmentResponse
from apideck.model.create_drive_group_response import CreateDriveGroupResponse
from apideck.model.create_drive_response import CreateDriveResponse
from apideck.model.create_ecommerce_customer_response import CreateEcommerceCustomerResponse
from apideck.model.create_ecommerce_order_response import CreateEcommerceOrderResponse
from apideck.model.create_employee_response import CreateEmployeeResponse
from apideck.model.create_file_request import CreateFileRequest
from apideck.model.create_file_response import CreateFileResponse
from apideck.model.create_folder_request import CreateFolderRequest
from apideck.model.create_folder_response import CreateFolderResponse
from apideck.model.create_hris_company_response import CreateHrisCompanyResponse
from apideck.model.create_invoice_item_response import CreateInvoiceItemResponse
from apideck.model.create_invoice_response import CreateInvoiceResponse
from apideck.model.create_item_response import CreateItemResponse
from apideck.model.create_job_response import CreateJobResponse
from apideck.model.create_journal_entry_response import CreateJournalEntryResponse
from apideck.model.create_lead_response import CreateLeadResponse
from apideck.model.create_ledger_account_response import CreateLedgerAccountResponse
from apideck.model.create_location_response import CreateLocationResponse
from apideck.model.create_merchant_response import CreateMerchantResponse
from apideck.model.create_message_response import CreateMessageResponse
from apideck.model.create_modifier_group_response import CreateModifierGroupResponse
from apideck.model.create_modifier_response import CreateModifierResponse
from apideck.model.create_note_response import CreateNoteResponse
from apideck.model.create_opportunity_response import CreateOpportunityResponse
from apideck.model.create_order_response import CreateOrderResponse
from apideck.model.create_order_type_response import CreateOrderTypeResponse
from apideck.model.create_payment_response import CreatePaymentResponse
from apideck.model.create_pipeline_response import CreatePipelineResponse
from apideck.model.create_pos_payment_response import CreatePosPaymentResponse
from apideck.model.create_product_response import CreateProductResponse
from apideck.model.create_purchase_order_response import CreatePurchaseOrderResponse
from apideck.model.create_session_response import CreateSessionResponse
from apideck.model.create_session_response_data import CreateSessionResponseData
from apideck.model.create_shared_link_response import CreateSharedLinkResponse
from apideck.model.create_supplier_response import CreateSupplierResponse
from apideck.model.create_tax_rate_response import CreateTaxRateResponse
from apideck.model.create_tender_response import CreateTenderResponse
from apideck.model.create_ticket_response import CreateTicketResponse
from apideck.model.create_time_off_request_response import CreateTimeOffRequestResponse
from apideck.model.create_upload_session_request import CreateUploadSessionRequest
from apideck.model.create_upload_session_response import CreateUploadSessionResponse
from apideck.model.create_user_response import CreateUserResponse
from apideck.model.create_webhook_request import CreateWebhookRequest
from apideck.model.create_webhook_response import CreateWebhookResponse
from apideck.model.credit_note import CreditNote
from apideck.model.crm_event_type import CrmEventType
from apideck.model.currency import Currency
from apideck.model.custom_field import CustomField
from apideck.model.custom_field_finder import CustomFieldFinder
from apideck.model.custom_mapping import CustomMapping
from apideck.model.customer import Customer
from apideck.model.customers_filter import CustomersFilter
from apideck.model.deduction import Deduction
from apideck.model.delete_activity_response import DeleteActivityResponse
from apideck.model.delete_applicant_response import DeleteApplicantResponse
from apideck.model.delete_application_response import DeleteApplicationResponse
from apideck.model.delete_bill_response import DeleteBillResponse
from apideck.model.delete_comment_response import DeleteCommentResponse
from apideck.model.delete_company_response import DeleteCompanyResponse
from apideck.model.delete_consumer_response import DeleteConsumerResponse
from apideck.model.delete_contact_response import DeleteContactResponse
from apideck.model.delete_credit_note_response import DeleteCreditNoteResponse
from apideck.model.delete_customer_response import DeleteCustomerResponse
from apideck.model.delete_department_response import DeleteDepartmentResponse
from apideck.model.delete_drive_group_response import DeleteDriveGroupResponse
from apideck.model.delete_drive_response import DeleteDriveResponse
from apideck.model.delete_ecommerce_customer_response import DeleteEcommerceCustomerResponse
from apideck.model.delete_ecommerce_order_response import DeleteEcommerceOrderResponse
from apideck.model.delete_employee_response import DeleteEmployeeResponse
from apideck.model.delete_file_response import DeleteFileResponse
from apideck.model.delete_folder_response import DeleteFolderResponse
from apideck.model.delete_hris_company_response import DeleteHrisCompanyResponse
from apideck.model.delete_invoice_item_response import DeleteInvoiceItemResponse
from apideck.model.delete_invoice_response import DeleteInvoiceResponse
from apideck.model.delete_item_response import DeleteItemResponse
from apideck.model.delete_job_response import DeleteJobResponse
from apideck.model.delete_journal_entry_response import DeleteJournalEntryResponse
from apideck.model.delete_lead_response import DeleteLeadResponse
from apideck.model.delete_ledger_account_response import DeleteLedgerAccountResponse
from apideck.model.delete_location_response import DeleteLocationResponse
from apideck.model.delete_merchant_response import DeleteMerchantResponse
from apideck.model.delete_message_response import DeleteMessageResponse
from apideck.model.delete_modifier_group_response import DeleteModifierGroupResponse
from apideck.model.delete_modifier_response import DeleteModifierResponse
from apideck.model.delete_note_response import DeleteNoteResponse
from apideck.model.delete_opportunity_response import DeleteOpportunityResponse
from apideck.model.delete_order_response import DeleteOrderResponse
from apideck.model.delete_order_type_response import DeleteOrderTypeResponse
from apideck.model.delete_payment_response import DeletePaymentResponse
from apideck.model.delete_pipeline_response import DeletePipelineResponse
from apideck.model.delete_pos_payment_response import DeletePosPaymentResponse
from apideck.model.delete_product_response import DeleteProductResponse
from apideck.model.delete_purchase_order_response import DeletePurchaseOrderResponse
from apideck.model.delete_shared_link_response import DeleteSharedLinkResponse
from apideck.model.delete_supplier_response import DeleteSupplierResponse
from apideck.model.delete_tax_rate_response import DeleteTaxRateResponse
from apideck.model.delete_tender_response import DeleteTenderResponse
from apideck.model.delete_ticket_response import DeleteTicketResponse
from apideck.model.delete_time_off_request_response import DeleteTimeOffRequestResponse
from apideck.model.delete_upload_session_response import DeleteUploadSessionResponse
from apideck.model.delete_user_response import DeleteUserResponse
from apideck.model.delete_webhook_response import DeleteWebhookResponse
from apideck.model.delivery_url import DeliveryUrl
from apideck.model.department import Department
from apideck.model.drive import Drive
from apideck.model.drive_group import DriveGroup
from apideck.model.drive_groups_filter import DriveGroupsFilter
from apideck.model.drives_filter import DrivesFilter
from apideck.model.ecommerce_address import EcommerceAddress
from apideck.model.ecommerce_customer import EcommerceCustomer
from apideck.model.ecommerce_customer_addresses import EcommerceCustomerAddresses
from apideck.model.ecommerce_customers_filter import EcommerceCustomersFilter
from apideck.model.ecommerce_discount import EcommerceDiscount
from apideck.model.ecommerce_order import EcommerceOrder
from apideck.model.ecommerce_order_line_item import EcommerceOrderLineItem
from apideck.model.ecommerce_order_status import EcommerceOrderStatus
from apideck.model.ecommerce_orders_filter import EcommerceOrdersFilter
from apideck.model.ecommerce_product import EcommerceProduct
from apideck.model.ecommerce_product_categories import EcommerceProductCategories
from apideck.model.ecommerce_product_images import EcommerceProductImages
from apideck.model.ecommerce_product_images1 import EcommerceProductImages1
from apideck.model.ecommerce_product_options import EcommerceProductOptions
from apideck.model.ecommerce_product_options1 import EcommerceProductOptions1
from apideck.model.ecommerce_product_variants import EcommerceProductVariants
from apideck.model.ecommerce_store import EcommerceStore
from apideck.model.email import Email
from apideck.model.employee import Employee
from apideck.model.employee_compensation import EmployeeCompensation
from apideck.model.employee_employment_role import EmployeeEmploymentRole
from apideck.model.employee_job import EmployeeJob
from apideck.model.employee_list import EmployeeList
from apideck.model.employee_manager import EmployeeManager
from apideck.model.employee_payroll import EmployeePayroll
from apideck.model.employee_schedules import EmployeeSchedules
from apideck.model.employees_filter import EmployeesFilter
from apideck.model.employees_sort import EmployeesSort
from apideck.model.employment_status import EmploymentStatus
from apideck.model.error import Error
from apideck.model.execute_base_url import ExecuteBaseUrl
from apideck.model.execute_webhook_event_request import ExecuteWebhookEventRequest
from apideck.model.execute_webhook_events_request import ExecuteWebhookEventsRequest
from apideck.model.execute_webhook_response import ExecuteWebhookResponse
from apideck.model.file_storage_event_type import FileStorageEventType
from apideck.model.file_type import FileType
from apideck.model.files_filter import FilesFilter
from apideck.model.files_search import FilesSearch
from apideck.model.files_sort import FilesSort
from apideck.model.folder import Folder
from apideck.model.form_field import FormField
from apideck.model.form_field_option import FormFieldOption
from apideck.model.form_field_option_group import FormFieldOptionGroup
from apideck.model.gender import Gender
from apideck.model.get_activities_response import GetActivitiesResponse
from apideck.model.get_activity_response import GetActivityResponse
from apideck.model.get_api_resource_coverage_response import GetApiResourceCoverageResponse
from apideck.model.get_api_resource_response import GetApiResourceResponse
from apideck.model.get_api_response import GetApiResponse
from apideck.model.get_apis_response import GetApisResponse
from apideck.model.get_applicant_response import GetApplicantResponse
from apideck.model.get_applicants_response import GetApplicantsResponse
from apideck.model.get_application_response import GetApplicationResponse
from apideck.model.get_applications_response import GetApplicationsResponse
from apideck.model.get_balance_sheet_response import GetBalanceSheetResponse
from apideck.model.get_bill_response import GetBillResponse
from apideck.model.get_bills_response import GetBillsResponse
from apideck.model.get_collection_response import GetCollectionResponse
from apideck.model.get_collection_tags_response import GetCollectionTagsResponse
from apideck.model.get_collection_user_response import GetCollectionUserResponse
from apideck.model.get_collection_users_response import GetCollectionUsersResponse
from apideck.model.get_collections_response import GetCollectionsResponse
from apideck.model.get_comment_response import GetCommentResponse
from apideck.model.get_comments_response import GetCommentsResponse
from apideck.model.get_companies_response import GetCompaniesResponse
from apideck.model.get_company_info_response import GetCompanyInfoResponse
from apideck.model.get_company_response import GetCompanyResponse
from apideck.model.get_connection_response import GetConnectionResponse
from apideck.model.get_connections_response import GetConnectionsResponse
from apideck.model.get_connector_resource_example_response import GetConnectorResourceExampleResponse
from apideck.model.get_connector_resource_example_response_data import GetConnectorResourceExampleResponseData
from apideck.model.get_connector_resource_response import GetConnectorResourceResponse
from apideck.model.get_connector_resource_schema_response import GetConnectorResourceSchemaResponse
from apideck.model.get_connector_response import GetConnectorResponse
from apideck.model.get_connectors_response import GetConnectorsResponse
from apideck.model.get_consumer_response import GetConsumerResponse
from apideck.model.get_consumers_response import GetConsumersResponse
from apideck.model.get_consumers_response_data import GetConsumersResponseData
from apideck.model.get_contact_response import GetContactResponse
from apideck.model.get_contacts_response import GetContactsResponse
from apideck.model.get_credit_note_response import GetCreditNoteResponse
from apideck.model.get_credit_notes_response import GetCreditNotesResponse
from apideck.model.get_custom_fields_response import GetCustomFieldsResponse
from apideck.model.get_custom_mapping_response import GetCustomMappingResponse
from apideck.model.get_customer_response import GetCustomerResponse
from apideck.model.get_customers_response import GetCustomersResponse
from apideck.model.get_department_response import GetDepartmentResponse
from apideck.model.get_departments_response import GetDepartmentsResponse
from apideck.model.get_drive_group_response import GetDriveGroupResponse
from apideck.model.get_drive_groups_response import GetDriveGroupsResponse
from apideck.model.get_drive_response import GetDriveResponse
from apideck.model.get_drives_response import GetDrivesResponse
from apideck.model.get_ecommerce_customer_response import GetEcommerceCustomerResponse
from apideck.model.get_ecommerce_customers_response import GetEcommerceCustomersResponse
from apideck.model.get_ecommerce_order_response import GetEcommerceOrderResponse
from apideck.model.get_ecommerce_orders_response import GetEcommerceOrdersResponse
from apideck.model.get_employee_payroll_response import GetEmployeePayrollResponse
from apideck.model.get_employee_payrolls_response import GetEmployeePayrollsResponse
from apideck.model.get_employee_response import GetEmployeeResponse
from apideck.model.get_employee_schedules_response import GetEmployeeSchedulesResponse
from apideck.model.get_employees_response import GetEmployeesResponse
from apideck.model.get_file_response import GetFileResponse
from apideck.model.get_files_response import GetFilesResponse
from apideck.model.get_folder_response import GetFolderResponse
from apideck.model.get_folders_response import GetFoldersResponse
from apideck.model.get_hris_companies_response import GetHrisCompaniesResponse
from apideck.model.get_hris_company_response import GetHrisCompanyResponse
from apideck.model.get_hris_job_response import GetHrisJobResponse
from apideck.model.get_hris_jobs_response import GetHrisJobsResponse
from apideck.model.get_invoice_item_response import GetInvoiceItemResponse
from apideck.model.get_invoice_items_response import GetInvoiceItemsResponse
from apideck.model.get_invoice_response import GetInvoiceResponse
from apideck.model.get_invoices_response import GetInvoicesResponse
from apideck.model.get_item_response import GetItemResponse
from apideck.model.get_items_response import GetItemsResponse
from apideck.model.get_job_response import GetJobResponse
from apideck.model.get_jobs_response import GetJobsResponse
from apideck.model.get_journal_entries_response import GetJournalEntriesResponse
from apideck.model.get_journal_entry_response import GetJournalEntryResponse
from apideck.model.get_lead_response import GetLeadResponse
from apideck.model.get_leads_response import GetLeadsResponse
from apideck.model.get_ledger_account_response import GetLedgerAccountResponse
from apideck.model.get_ledger_accounts_response import GetLedgerAccountsResponse
from apideck.model.get_location_response import GetLocationResponse
from apideck.model.get_locations_response import GetLocationsResponse
from apideck.model.get_logs_response import GetLogsResponse
from apideck.model.get_merchant_response import GetMerchantResponse
from apideck.model.get_merchants_response import GetMerchantsResponse
from apideck.model.get_message_response import GetMessageResponse
from apideck.model.get_messages_response import GetMessagesResponse
from apideck.model.get_modifier_group_response import GetModifierGroupResponse
from apideck.model.get_modifier_groups_response import GetModifierGroupsResponse
from apideck.model.get_modifier_response import GetModifierResponse
from apideck.model.get_modifiers_response import GetModifiersResponse
from apideck.model.get_note_response import GetNoteResponse
from apideck.model.get_notes_response import GetNotesResponse
from apideck.model.get_opportunities_response import GetOpportunitiesResponse
from apideck.model.get_opportunity_response import GetOpportunityResponse
from apideck.model.get_order_response import GetOrderResponse
from apideck.model.get_order_type_response import GetOrderTypeResponse
from apideck.model.get_order_types_response import GetOrderTypesResponse
from apideck.model.get_orders_response import GetOrdersResponse
from apideck.model.get_payment_response import GetPaymentResponse
from apideck.model.get_payments_response import GetPaymentsResponse
from apideck.model.get_payroll_response import GetPayrollResponse
from apideck.model.get_payrolls_response import GetPayrollsResponse
from apideck.model.get_pipeline_response import GetPipelineResponse
from apideck.model.get_pipelines_response import GetPipelinesResponse
from apideck.model.get_pos_payment_response import GetPosPaymentResponse
from apideck.model.get_pos_payments_response import GetPosPaymentsResponse
from apideck.model.get_product_response import GetProductResponse
from apideck.model.get_products_response import GetProductsResponse
from apideck.model.get_profit_and_loss_response import GetProfitAndLossResponse
from apideck.model.get_purchase_order_response import GetPurchaseOrderResponse
from apideck.model.get_purchase_orders_response import GetPurchaseOrdersResponse
from apideck.model.get_resource_example_response import GetResourceExampleResponse
from apideck.model.get_resource_schema_response import GetResourceSchemaResponse
from apideck.model.get_shared_link_response import GetSharedLinkResponse
from apideck.model.get_shared_links_response import GetSharedLinksResponse
from apideck.model.get_store_response import GetStoreResponse
from apideck.model.get_stores_response import GetStoresResponse
from apideck.model.get_supplier_response import GetSupplierResponse
from apideck.model.get_suppliers_response import GetSuppliersResponse
from apideck.model.get_tax_rate_response import GetTaxRateResponse
from apideck.model.get_tax_rates_response import GetTaxRatesResponse
from apideck.model.get_tender_response import GetTenderResponse
from apideck.model.get_tenders_response import GetTendersResponse
from apideck.model.get_ticket_response import GetTicketResponse
from apideck.model.get_tickets_response import GetTicketsResponse
from apideck.model.get_time_off_request_response import GetTimeOffRequestResponse
from apideck.model.get_time_off_requests_response import GetTimeOffRequestsResponse
from apideck.model.get_upload_session_response import GetUploadSessionResponse
from apideck.model.get_user_response import GetUserResponse
from apideck.model.get_users_response import GetUsersResponse
from apideck.model.get_webhook_event_logs_response import GetWebhookEventLogsResponse
from apideck.model.get_webhook_response import GetWebhookResponse
from apideck.model.get_webhooks_response import GetWebhooksResponse
from apideck.model.hris_company import HrisCompany
from apideck.model.hris_event_type import HrisEventType
from apideck.model.hris_job import HrisJob
from apideck.model.hris_job_location import HrisJobLocation
from apideck.model.hris_jobs import HrisJobs
from apideck.model.idempotency_key import IdempotencyKey
from apideck.model.integration_state import IntegrationState
from apideck.model.invoice import Invoice
from apideck.model.invoice_item import InvoiceItem
from apideck.model.invoice_item_asset_account import InvoiceItemAssetAccount
from apideck.model.invoice_item_expense_account import InvoiceItemExpenseAccount
from apideck.model.invoice_item_income_account import InvoiceItemIncomeAccount
from apideck.model.invoice_item_sales_details import InvoiceItemSalesDetails
from apideck.model.invoice_items_filter import InvoiceItemsFilter
from apideck.model.invoice_line_item import InvoiceLineItem
from apideck.model.invoice_response import InvoiceResponse
from apideck.model.invoices_sort import InvoicesSort
from apideck.model.issue_tracking_event_type import IssueTrackingEventType
from apideck.model.issues_filter import IssuesFilter
from apideck.model.item import Item
from apideck.model.job import Job
from apideck.model.job_links import JobLinks
from apideck.model.job_salary import JobSalary
from apideck.model.job_status import JobStatus
from apideck.model.journal_entry import JournalEntry
from apideck.model.journal_entry_line_item import JournalEntryLineItem
from apideck.model.lead import Lead
from apideck.model.lead_event_type import LeadEventType
from apideck.model.leads_filter import LeadsFilter
from apideck.model.leads_sort import LeadsSort
from apideck.model.ledger_account import LedgerAccount
from apideck.model.ledger_account_categories import LedgerAccountCategories
from apideck.model.ledger_account_parent_account import LedgerAccountParentAccount
from apideck.model.ledger_accounts import LedgerAccounts
from apideck.model.linked_connector_resource import LinkedConnectorResource
from apideck.model.linked_customer import LinkedCustomer
from apideck.model.linked_ecommerce_customer import LinkedEcommerceCustomer
from apideck.model.linked_ecommerce_order import LinkedEcommerceOrder
from apideck.model.linked_folder import LinkedFolder
from apideck.model.linked_invoice_item import LinkedInvoiceItem
from apideck.model.linked_ledger_account import LinkedLedgerAccount
from apideck.model.linked_parent_customer import LinkedParentCustomer
from apideck.model.linked_supplier import LinkedSupplier
from apideck.model.linked_tax_rate import LinkedTaxRate
from apideck.model.linked_tracking_category import LinkedTrackingCategory
from apideck.model.links import Links
from apideck.model.location import Location
from apideck.model.log import Log
from apideck.model.log_operation import LogOperation
from apideck.model.log_service import LogService
from apideck.model.logs_filter import LogsFilter
from apideck.model.merchant import Merchant
from apideck.model.message import Message
from apideck.model.meta import Meta
from apideck.model.meta_cursors import MetaCursors
from apideck.model.modifier import Modifier
from apideck.model.modifier_group import ModifierGroup
from apideck.model.modifier_group_filter import ModifierGroupFilter
from apideck.model.not_found_response import NotFoundResponse
from apideck.model.not_implemented_response import NotImplementedResponse
from apideck.model.note import Note
from apideck.model.o_auth_grant_type import OAuthGrantType
from apideck.model.offer import Offer
from apideck.model.opportunities_filter import OpportunitiesFilter
from apideck.model.opportunities_sort import OpportunitiesSort
from apideck.model.opportunity import Opportunity
from apideck.model.order import Order
from apideck.model.order_customers import OrderCustomers
from apideck.model.order_discounts import OrderDiscounts
from apideck.model.order_fulfillments import OrderFulfillments
from apideck.model.order_line_items import OrderLineItems
from apideck.model.order_payments import OrderPayments
from apideck.model.order_pickup_details import OrderPickupDetails
from apideck.model.order_pickup_details_curbside_pickup_details import OrderPickupDetailsCurbsidePickupDetails
from apideck.model.order_pickup_details_recipient import OrderPickupDetailsRecipient
from apideck.model.order_refunds import OrderRefunds
from apideck.model.order_tenders import OrderTenders
from apideck.model.order_type import OrderType
from apideck.model.owner import Owner
from apideck.model.pagination_coverage import PaginationCoverage
from apideck.model.pass_through_query import PassThroughQuery
from apideck.model.payment import Payment
from apideck.model.payment_allocations import PaymentAllocations
from apideck.model.payment_card import PaymentCard
from apideck.model.payment_frequency import PaymentFrequency
from apideck.model.payment_required_response import PaymentRequiredResponse
from apideck.model.payment_unit import PaymentUnit
from apideck.model.payments_filter import PaymentsFilter
from apideck.model.payroll import Payroll
from apideck.model.payroll_totals import PayrollTotals
from apideck.model.payrolls_filter import PayrollsFilter
from apideck.model.person import Person
from apideck.model.phone_number import PhoneNumber
from apideck.model.pipeline import Pipeline
from apideck.model.pipeline_stages import PipelineStages
from apideck.model.pos_bank_account import PosBankAccount
from apideck.model.pos_bank_account_ach_details import PosBankAccountAchDetails
from apideck.model.pos_payment import PosPayment
from apideck.model.pos_payment_card_details import PosPaymentCardDetails
from apideck.model.pos_payment_external_details import PosPaymentExternalDetails
from apideck.model.price import Price
from apideck.model.probation_period import ProbationPeriod
from apideck.model.profit_and_loss import ProfitAndLoss
from apideck.model.profit_and_loss_expenses import ProfitAndLossExpenses
from apideck.model.profit_and_loss_filter import ProfitAndLossFilter
from apideck.model.profit_and_loss_gross_profit import ProfitAndLossGrossProfit
from apideck.model.profit_and_loss_income import ProfitAndLossIncome
from apideck.model.profit_and_loss_net_income import ProfitAndLossNetIncome
from apideck.model.profit_and_loss_net_operating_income import ProfitAndLossNetOperatingIncome
from apideck.model.profit_and_loss_record import ProfitAndLossRecord
from apideck.model.profit_and_loss_records import ProfitAndLossRecords
from apideck.model.profit_and_loss_section import ProfitAndLossSection
from apideck.model.purchase_order import PurchaseOrder
from apideck.model.request_count_allocation import RequestCountAllocation
from apideck.model.request_rate import RequestRate
from apideck.model.resolve_webhook_event_request import ResolveWebhookEventRequest
from apideck.model.resolve_webhook_events_request import ResolveWebhookEventsRequest
from apideck.model.resolve_webhook_response import ResolveWebhookResponse
from apideck.model.resource_example import ResourceExample
from apideck.model.resource_status import ResourceStatus
from apideck.model.schedule import Schedule
from apideck.model.schedule_work_pattern import ScheduleWorkPattern
from apideck.model.schedule_work_pattern_odd_weeks import ScheduleWorkPatternOddWeeks
from apideck.model.schema_support import SchemaSupport
from apideck.model.service_charge import ServiceCharge
from apideck.model.service_charges import ServiceCharges
from apideck.model.session import Session
from apideck.model.session_settings import SessionSettings
from apideck.model.session_theme import SessionTheme
from apideck.model.shared_link import SharedLink
from apideck.model.shared_link_target import SharedLinkTarget
from apideck.model.simple_form_field_option import SimpleFormFieldOption
from apideck.model.social_link import SocialLink
from apideck.model.sort_direction import SortDirection
from apideck.model.status import Status
from apideck.model.supplier import Supplier
from apideck.model.suppliers_filter import SuppliersFilter
from apideck.model.supported_property import SupportedProperty
from apideck.model.supported_property_child_properties import SupportedPropertyChildProperties
from apideck.model.tags import Tags
from apideck.model.tax import Tax
from apideck.model.tax_rate import TaxRate
from apideck.model.tax_rates_filter import TaxRatesFilter
from apideck.model.team import Team
from apideck.model.tender import Tender
from apideck.model.ticket import Ticket
from apideck.model.tickets_sort import TicketsSort
from apideck.model.time_off_request import TimeOffRequest
from apideck.model.time_off_request_notes import TimeOffRequestNotes
from apideck.model.time_off_requests_filter import TimeOffRequestsFilter
from apideck.model.too_many_requests_response import TooManyRequestsResponse
from apideck.model.too_many_requests_response_detail import TooManyRequestsResponseDetail
from apideck.model.tracking_item import TrackingItem
from apideck.model.unauthorized_response import UnauthorizedResponse
from apideck.model.unexpected_error_response import UnexpectedErrorResponse
from apideck.model.unified_api_id import UnifiedApiId
from apideck.model.unified_file import UnifiedFile
from apideck.model.unified_file_permissions import UnifiedFilePermissions
from apideck.model.unified_id import UnifiedId
from apideck.model.unprocessable_response import UnprocessableResponse
from apideck.model.update_activity_response import UpdateActivityResponse
from apideck.model.update_applicant_response import UpdateApplicantResponse
from apideck.model.update_application_response import UpdateApplicationResponse
from apideck.model.update_bill_response import UpdateBillResponse
from apideck.model.update_comment_response import UpdateCommentResponse
from apideck.model.update_company_response import UpdateCompanyResponse
from apideck.model.update_connection_response import UpdateConnectionResponse
from apideck.model.update_consumer_request import UpdateConsumerRequest
from apideck.model.update_consumer_response import UpdateConsumerResponse
from apideck.model.update_contact_response import UpdateContactResponse
from apideck.model.update_credit_note_response import UpdateCreditNoteResponse
from apideck.model.update_custom_mapping_request import UpdateCustomMappingRequest
from apideck.model.update_custom_mapping_response import UpdateCustomMappingResponse
from apideck.model.update_customer_response import UpdateCustomerResponse
from apideck.model.update_department_response import UpdateDepartmentResponse
from apideck.model.update_drive_group_response import UpdateDriveGroupResponse
from apideck.model.update_drive_response import UpdateDriveResponse
from apideck.model.update_ecommerce_customer_response import UpdateEcommerceCustomerResponse
from apideck.model.update_ecommerce_order_response import UpdateEcommerceOrderResponse
from apideck.model.update_employee_response import UpdateEmployeeResponse
from apideck.model.update_file_request import UpdateFileRequest
from apideck.model.update_file_response import UpdateFileResponse
from apideck.model.update_folder_request import UpdateFolderRequest
from apideck.model.update_folder_response import UpdateFolderResponse
from apideck.model.update_hris_company_response import UpdateHrisCompanyResponse
from apideck.model.update_invoice_items_response import UpdateInvoiceItemsResponse
from apideck.model.update_invoice_response import UpdateInvoiceResponse
from apideck.model.update_item_response import UpdateItemResponse
from apideck.model.update_job_response import UpdateJobResponse
from apideck.model.update_journal_entry_response import UpdateJournalEntryResponse
from apideck.model.update_lead_response import UpdateLeadResponse
from apideck.model.update_ledger_account_response import UpdateLedgerAccountResponse
from apideck.model.update_location_response import UpdateLocationResponse
from apideck.model.update_merchant_response import UpdateMerchantResponse
from apideck.model.update_message_response import UpdateMessageResponse
from apideck.model.update_modifier_group_response import UpdateModifierGroupResponse
from apideck.model.update_modifier_response import UpdateModifierResponse
from apideck.model.update_note_response import UpdateNoteResponse
from apideck.model.update_opportunity_response import UpdateOpportunityResponse
from apideck.model.update_order_response import UpdateOrderResponse
from apideck.model.update_order_type_response import UpdateOrderTypeResponse
from apideck.model.update_payment_response import UpdatePaymentResponse
from apideck.model.update_pipeline_response import UpdatePipelineResponse
from apideck.model.update_pos_payment_response import UpdatePosPaymentResponse
from apideck.model.update_product_response import UpdateProductResponse
from apideck.model.update_purchase_order_response import UpdatePurchaseOrderResponse
from apideck.model.update_shared_link_response import UpdateSharedLinkResponse
from apideck.model.update_supplier_response import UpdateSupplierResponse
from apideck.model.update_tax_rate_response import UpdateTaxRateResponse
from apideck.model.update_tender_response import UpdateTenderResponse
from apideck.model.update_ticket_response import UpdateTicketResponse
from apideck.model.update_time_off_request_response import UpdateTimeOffRequestResponse
from apideck.model.update_upload_session_response import UpdateUploadSessionResponse
from apideck.model.update_user_response import UpdateUserResponse
from apideck.model.update_webhook_request import UpdateWebhookRequest
from apideck.model.update_webhook_response import UpdateWebhookResponse
from apideck.model.upload_session import UploadSession
from apideck.model.url import Url
from apideck.model.user import User
from apideck.model.vault_event_type import VaultEventType
from apideck.model.virtual_webhooks import VirtualWebhooks
from apideck.model.wallet_details import WalletDetails
from apideck.model.webhook import Webhook
from apideck.model.webhook_event import WebhookEvent
from apideck.model.webhook_event_log import WebhookEventLog
from apideck.model.webhook_event_log_attempts import WebhookEventLogAttempts
from apideck.model.webhook_event_log_service import WebhookEventLogService
from apideck.model.webhook_event_logs_filter import WebhookEventLogsFilter
from apideck.model.webhook_event_logs_filter_service import WebhookEventLogsFilterService
from apideck.model.webhook_event_type import WebhookEventType
from apideck.model.webhook_subscription import WebhookSubscription
from apideck.model.webhook_support import WebhookSupport
from apideck.model.website import Website



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.file_type import FileType
from apideck.model.linked_folder import LinkedFolder
from apideck.model.owner import Owner
from apideck.model.unified_file_permissions import UnifiedFilePermissions
globals()['FileType'] = FileType
globals()['LinkedFolder'] = LinkedFolder
globals()['Owner'] = Owner
globals()['UnifiedFilePermissions'] = UnifiedFilePermissions
from apideck.model.unified_file import UnifiedFile


class TestUnifiedFile(unittest.TestCase):
    """UnifiedFile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUnifiedFile(self):
        """Test UnifiedFile"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UnifiedFile()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.ecommerce_api import EcommerceApi  # noqa: E501


class TestEcommerceApi(unittest.TestCase):
    """EcommerceApi unit test stubs"""

    def setUp(self):
        self.api = EcommerceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_customers_all(self):
        """Test case for customers_all

        List Customers  # noqa: E501
        """
        pass

    def test_customers_one(self):
        """Test case for customers_one

        Get Customer  # noqa: E501
        """
        pass

    def test_orders_all(self):
        """Test case for orders_all

        List Orders  # noqa: E501
        """
        pass

    def test_orders_one(self):
        """Test case for orders_one

        Get Order  # noqa: E501
        """
        pass

    def test_products_all(self):
        """Test case for products_all

        List Products  # noqa: E501
        """
        pass

    def test_products_one(self):
        """Test case for products_one

        Get Product  # noqa: E501
        """
        pass

    def test_stores_one(self):
        """Test case for stores_one

        Get Store  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.connector_event import ConnectorEvent
from apideck.model.connector_oauth_scopes1 import ConnectorOauthScopes1
from apideck.model.linked_connector_resource import LinkedConnectorResource
from apideck.model.unified_api_id import UnifiedApiId
globals()['ConnectorEvent'] = ConnectorEvent
globals()['ConnectorOauthScopes1'] = ConnectorOauthScopes1
globals()['LinkedConnectorResource'] = LinkedConnectorResource
globals()['UnifiedApiId'] = UnifiedApiId
from apideck.model.connector_unified_apis import ConnectorUnifiedApis


class TestConnectorUnifiedApis(unittest.TestCase):
    """ConnectorUnifiedApis unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConnectorUnifiedApis(self):
        """Test ConnectorUnifiedApis"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConnectorUnifiedApis()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.accounting_event_type import AccountingEventType


class TestAccountingEventType(unittest.TestCase):
    """AccountingEventType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccountingEventType(self):
        """Test AccountingEventType"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AccountingEventType()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.pos_api import PosApi  # noqa: E501


class TestPosApi(unittest.TestCase):
    """PosApi unit test stubs"""

    def setUp(self):
        self.api = PosApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_items_add(self):
        """Test case for items_add

        Create Item  # noqa: E501
        """
        pass

    def test_items_all(self):
        """Test case for items_all

        List Items  # noqa: E501
        """
        pass

    def test_items_delete(self):
        """Test case for items_delete

        Delete Item  # noqa: E501
        """
        pass

    def test_items_one(self):
        """Test case for items_one

        Get Item  # noqa: E501
        """
        pass

    def test_items_update(self):
        """Test case for items_update

        Update Item  # noqa: E501
        """
        pass

    def test_locations_add(self):
        """Test case for locations_add

        Create Location  # noqa: E501
        """
        pass

    def test_locations_all(self):
        """Test case for locations_all

        List Locations  # noqa: E501
        """
        pass

    def test_locations_delete(self):
        """Test case for locations_delete

        Delete Location  # noqa: E501
        """
        pass

    def test_locations_one(self):
        """Test case for locations_one

        Get Location  # noqa: E501
        """
        pass

    def test_locations_update(self):
        """Test case for locations_update

        Update Location  # noqa: E501
        """
        pass

    def test_merchants_add(self):
        """Test case for merchants_add

        Create Merchant  # noqa: E501
        """
        pass

    def test_merchants_all(self):
        """Test case for merchants_all

        List Merchants  # noqa: E501
        """
        pass

    def test_merchants_delete(self):
        """Test case for merchants_delete

        Delete Merchant  # noqa: E501
        """
        pass

    def test_merchants_one(self):
        """Test case for merchants_one

        Get Merchant  # noqa: E501
        """
        pass

    def test_merchants_update(self):
        """Test case for merchants_update

        Update Merchant  # noqa: E501
        """
        pass

    def test_modifier_groups_add(self):
        """Test case for modifier_groups_add

        Create Modifier Group  # noqa: E501
        """
        pass

    def test_modifier_groups_all(self):
        """Test case for modifier_groups_all

        List Modifier Groups  # noqa: E501
        """
        pass

    def test_modifier_groups_delete(self):
        """Test case for modifier_groups_delete

        Delete Modifier Group  # noqa: E501
        """
        pass

    def test_modifier_groups_one(self):
        """Test case for modifier_groups_one

        Get Modifier Group  # noqa: E501
        """
        pass

    def test_modifier_groups_update(self):
        """Test case for modifier_groups_update

        Update Modifier Group  # noqa: E501
        """
        pass

    def test_modifiers_add(self):
        """Test case for modifiers_add

        Create Modifier  # noqa: E501
        """
        pass

    def test_modifiers_all(self):
        """Test case for modifiers_all

        List Modifiers  # noqa: E501
        """
        pass

    def test_modifiers_delete(self):
        """Test case for modifiers_delete

        Delete Modifier  # noqa: E501
        """
        pass

    def test_modifiers_one(self):
        """Test case for modifiers_one

        Get Modifier  # noqa: E501
        """
        pass

    def test_modifiers_update(self):
        """Test case for modifiers_update

        Update Modifier  # noqa: E501
        """
        pass

    def test_order_types_add(self):
        """Test case for order_types_add

        Create Order Type  # noqa: E501
        """
        pass

    def test_order_types_all(self):
        """Test case for order_types_all

        List Order Types  # noqa: E501
        """
        pass

    def test_order_types_delete(self):
        """Test case for order_types_delete

        Delete Order Type  # noqa: E501
        """
        pass

    def test_order_types_one(self):
        """Test case for order_types_one

        Get Order Type  # noqa: E501
        """
        pass

    def test_order_types_update(self):
        """Test case for order_types_update

        Update Order Type  # noqa: E501
        """
        pass

    def test_orders_add(self):
        """Test case for orders_add

        Create Order  # noqa: E501
        """
        pass

    def test_orders_all(self):
        """Test case for orders_all

        List Orders  # noqa: E501
        """
        pass

    def test_orders_delete(self):
        """Test case for orders_delete

        Delete Order  # noqa: E501
        """
        pass

    def test_orders_one(self):
        """Test case for orders_one

        Get Order  # noqa: E501
        """
        pass

    def test_orders_pay(self):
        """Test case for orders_pay

        Pay Order  # noqa: E501
        """
        pass

    def test_orders_update(self):
        """Test case for orders_update

        Update Order  # noqa: E501
        """
        pass

    def test_payments_add(self):
        """Test case for payments_add

        Create Payment  # noqa: E501
        """
        pass

    def test_payments_all(self):
        """Test case for payments_all

        List Payments  # noqa: E501
        """
        pass

    def test_payments_delete(self):
        """Test case for payments_delete

        Delete Payment  # noqa: E501
        """
        pass

    def test_payments_one(self):
        """Test case for payments_one

        Get Payment  # noqa: E501
        """
        pass

    def test_payments_update(self):
        """Test case for payments_update

        Update Payment  # noqa: E501
        """
        pass

    def test_tenders_add(self):
        """Test case for tenders_add

        Create Tender  # noqa: E501
        """
        pass

    def test_tenders_all(self):
        """Test case for tenders_all

        List Tenders  # noqa: E501
        """
        pass

    def test_tenders_delete(self):
        """Test case for tenders_delete

        Delete Tender  # noqa: E501
        """
        pass

    def test_tenders_one(self):
        """Test case for tenders_one

        Get Tender  # noqa: E501
        """
        pass

    def test_tenders_update(self):
        """Test case for tenders_update

        Update Tender  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.ecommerce_product_categories import EcommerceProductCategories
from apideck.model.ecommerce_product_images import EcommerceProductImages
from apideck.model.ecommerce_product_options import EcommerceProductOptions
from apideck.model.ecommerce_product_variants import EcommerceProductVariants
globals()['EcommerceProductCategories'] = EcommerceProductCategories
globals()['EcommerceProductImages'] = EcommerceProductImages
globals()['EcommerceProductOptions'] = EcommerceProductOptions
globals()['EcommerceProductVariants'] = EcommerceProductVariants
from apideck.model.ecommerce_product import EcommerceProduct


class TestEcommerceProduct(unittest.TestCase):
    """EcommerceProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEcommerceProduct(self):
        """Test EcommerceProduct"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EcommerceProduct()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.address import Address
from apideck.model.custom_field import CustomField
from apideck.model.email import Email
from apideck.model.phone_number import PhoneNumber
from apideck.model.social_link import SocialLink
from apideck.model.tags import Tags
from apideck.model.website import Website
globals()['Address'] = Address
globals()['CustomField'] = CustomField
globals()['Email'] = Email
globals()['PhoneNumber'] = PhoneNumber
globals()['SocialLink'] = SocialLink
globals()['Tags'] = Tags
globals()['Website'] = Website
from apideck.model.contact import Contact


class TestContact(unittest.TestCase):
    """Contact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testContact(self):
        """Test Contact"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Contact()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.address import Address
from apideck.model.branch import Branch
from apideck.model.custom_field import CustomField
from apideck.model.department import Department
from apideck.model.job_links import JobLinks
from apideck.model.job_salary import JobSalary
from apideck.model.job_status import JobStatus
from apideck.model.tags import Tags
globals()['Address'] = Address
globals()['Branch'] = Branch
globals()['CustomField'] = CustomField
globals()['Department'] = Department
globals()['JobLinks'] = JobLinks
globals()['JobSalary'] = JobSalary
globals()['JobStatus'] = JobStatus
globals()['Tags'] = Tags
from apideck.model.job import Job


class TestJob(unittest.TestCase):
    """Job unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testJob(self):
        """Test Job"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Job()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.currency import Currency
from apideck.model.idempotency_key import IdempotencyKey
from apideck.model.order_customers import OrderCustomers
from apideck.model.order_discounts import OrderDiscounts
from apideck.model.order_fulfillments import OrderFulfillments
from apideck.model.order_line_items import OrderLineItems
from apideck.model.order_payments import OrderPayments
from apideck.model.order_refunds import OrderRefunds
from apideck.model.order_tenders import OrderTenders
from apideck.model.service_charges import ServiceCharges
globals()['Currency'] = Currency
globals()['IdempotencyKey'] = IdempotencyKey
globals()['OrderCustomers'] = OrderCustomers
globals()['OrderDiscounts'] = OrderDiscounts
globals()['OrderFulfillments'] = OrderFulfillments
globals()['OrderLineItems'] = OrderLineItems
globals()['OrderPayments'] = OrderPayments
globals()['OrderRefunds'] = OrderRefunds
globals()['OrderTenders'] = OrderTenders
globals()['ServiceCharges'] = ServiceCharges
from apideck.model.order import Order


class TestOrder(unittest.TestCase):
    """Order unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrder(self):
        """Test Order"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Order()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.accounting_api import AccountingApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from apideck.api.accounting_api import AccountingApi
from apideck.api.ats_api import AtsApi
from apideck.api.connector_api import ConnectorApi
from apideck.api.crm_api import CrmApi
from apideck.api.ecommerce_api import EcommerceApi
from apideck.api.file_storage_api import FileStorageApi
from apideck.api.hris_api import HrisApi
from apideck.api.issue_tracking_api import IssueTrackingApi
from apideck.api.lead_api import LeadApi
from apideck.api.pos_api import PosApi
from apideck.api.sms_api import SmsApi
from apideck.api.vault_api import VaultApi
from apideck.api.webhook_api import WebhookApi



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.ats_api import AtsApi  # noqa: E501


class TestAtsApi(unittest.TestCase):
    """AtsApi unit test stubs"""

    def setUp(self):
        self.api = AtsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_applicants_add(self):
        """Test case for applicants_add

        Create Applicant  # noqa: E501
        """
        pass

    def test_applicants_all(self):
        """Test case for applicants_all

        List Applicants  # noqa: E501
        """
        pass

    def test_applicants_delete(self):
        """Test case for applicants_delete

        Delete Applicant  # noqa: E501
        """
        pass

    def test_applicants_one(self):
        """Test case for applicants_one

        Get Applicant  # noqa: E501
        """
        pass

    def test_applicants_update(self):
        """Test case for applicants_update

        Update Applicant  # noqa: E501
        """
        pass

    def test_applications_add(self):
        """Test case for applications_add

        Create Application  # noqa: E501
        """
        pass

    def test_applications_all(self):
        """Test case for applications_all

        List Applications  # noqa: E501
        """
        pass

    def test_applications_delete(self):
        """Test case for applications_delete

        Delete Application  # noqa: E501
        """
        pass

    def test_applications_one(self):
        """Test case for applications_one

        Get Application  # noqa: E501
        """
        pass

    def test_applications_update(self):
        """Test case for applications_update

        Update Application  # noqa: E501
        """
        pass

    def test_jobs_all(self):
        """Test case for jobs_all

        List Jobs  # noqa: E501
        """
        pass

    def test_jobs_one(self):
        """Test case for jobs_one

        Get Job  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from apideck.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from apideck.exceptions import ApiAttributeError


def lazy_import():
    from apideck.model.currency import Currency
    from apideck.model.custom_field import CustomField
    from apideck.model.tags import Tags
    globals()['Currency'] = Currency
    globals()['CustomField'] = CustomField
    globals()['Tags'] = Tags


class Opportunity(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
        ('title',): {
            'min_length': 1,
        },
    }

    additional_properties_type = None

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'title': (str,),  # noqa: E501
            'primary_contact_id': (str, none_type,),  # noqa: E501
            'id': (str,),  # noqa: E501
            'description': (str, none_type,),  # noqa: E501
            'type': (str, none_type,),  # noqa: E501
            'monetary_amount': (float, none_type,),  # noqa: E501
            'currency': (Currency,),  # noqa: E501
            'win_probability': (float, none_type,),  # noqa: E501
            'expected_revenue': (float, none_type,),  # noqa: E501
            'close_date': (date, none_type,),  # noqa: E501
            'loss_reason_id': (str, none_type,),  # noqa: E501
            'loss_reason': (str, none_type,),  # noqa: E501
            'won_reason_id': (str, none_type,),  # noqa: E501
            'won_reason': (str, none_type,),  # noqa: E501
            'pipeline_id': (str, none_type,),  # noqa: E501
            'pipeline_stage_id': (str, none_type,),  # noqa: E501
            'source_id': (str, none_type,),  # noqa: E501
            'lead_id': (str, none_type,),  # noqa: E501
            'lead_source': (str, none_type,),  # noqa: E501
            'contact_id': (str, none_type,),  # noqa: E501
            'contact_ids': ([str],),  # noqa: E501
            'company_id': (str, none_type,),  # noqa: E501
            'company_name': (str, none_type,),  # noqa: E501
            'owner_id': (str, none_type,),  # noqa: E501
            'priority': (str, none_type,),  # noqa: E501
            'status': (str, none_type,),  # noqa: E501
            'status_id': (str, none_type,),  # noqa: E501
            'tags': (Tags,),  # noqa: E501
            'interaction_count': (float, none_type,),  # noqa: E501
            'custom_fields': ([CustomField],),  # noqa: E501
            'stage_last_changed_at': (datetime, none_type,),  # noqa: E501
            'last_activity_at': (str, none_type,),  # noqa: E501
            'deleted': (bool,),  # noqa: E501
            'date_stage_changed': (datetime, none_type,),  # noqa: E501
            'date_last_contacted': (datetime, none_type,),  # noqa: E501
            'date_lead_created': (datetime, none_type,),  # noqa: E501
            'custom_mappings': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'updated_by': (str, none_type,),  # noqa: E501
            'created_by': (str, none_type,),  # noqa: E501
            'updated_at': (datetime, none_type,),  # noqa: E501
            'created_at': (datetime, none_type,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'title': 'title',  # noqa: E501
        'primary_contact_id': 'primary_contact_id',  # noqa: E501
        'id': 'id',  # noqa: E501
        'description': 'description',  # noqa: E501
        'type': 'type',  # noqa: E501
        'monetary_amount': 'monetary_amount',  # noqa: E501
        'currency': 'currency',  # noqa: E501
        'win_probability': 'win_probability',  # noqa: E501
        'expected_revenue': 'expected_revenue',  # noqa: E501
        'close_date': 'close_date',  # noqa: E501
        'loss_reason_id': 'loss_reason_id',  # noqa: E501
        'loss_reason': 'loss_reason',  # noqa: E501
        'won_reason_id': 'won_reason_id',  # noqa: E501
        'won_reason': 'won_reason',  # noqa: E501
        'pipeline_id': 'pipeline_id',  # noqa: E501
        'pipeline_stage_id': 'pipeline_stage_id',  # noqa: E501
        'source_id': 'source_id',  # noqa: E501
        'lead_id': 'lead_id',  # noqa: E501
        'lead_source': 'lead_source',  # noqa: E501
        'contact_id': 'contact_id',  # noqa: E501
        'contact_ids': 'contact_ids',  # noqa: E501
        'company_id': 'company_id',  # noqa: E501
        'company_name': 'company_name',  # noqa: E501
        'owner_id': 'owner_id',  # noqa: E501
        'priority': 'priority',  # noqa: E501
        'status': 'status',  # noqa: E501
        'status_id': 'status_id',  # noqa: E501
        'tags': 'tags',  # noqa: E501
        'interaction_count': 'interaction_count',  # noqa: E501
        'custom_fields': 'custom_fields',  # noqa: E501
        'stage_last_changed_at': 'stage_last_changed_at',  # noqa: E501
        'last_activity_at': 'last_activity_at',  # noqa: E501
        'deleted': 'deleted',  # noqa: E501
        'date_stage_changed': 'date_stage_changed',  # noqa: E501
        'date_last_contacted': 'date_last_contacted',  # noqa: E501
        'date_lead_created': 'date_lead_created',  # noqa: E501
        'custom_mappings': 'custom_mappings',  # noqa: E501
        'updated_by': 'updated_by',  # noqa: E501
        'created_by': 'created_by',  # noqa: E501
        'updated_at': 'updated_at',  # noqa: E501
        'created_at': 'created_at',  # noqa: E501
    }

    read_only_vars = {
        'id',  # noqa: E501
        'expected_revenue',  # noqa: E501
        'interaction_count',  # noqa: E501
        'last_activity_at',  # noqa: E501
        'deleted',  # noqa: E501
        'date_stage_changed',  # noqa: E501
        'date_last_contacted',  # noqa: E501
        'date_lead_created',  # noqa: E501
        'updated_by',  # noqa: E501
        'created_by',  # noqa: E501
        'updated_at',  # noqa: E501
        'created_at',  # noqa: E501
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, title, primary_contact_id, *args, **kwargs):  # noqa: E501
        """Opportunity - a model defined in OpenAPI

        Args:
            title (str): The title or name of the opportunity.
            primary_contact_id (str, none_type): The unique identifier of the primary contact associated with the opportunity.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): A unique identifier for the opportunity.. [optional]  # noqa: E501
            description (str, none_type): A description of the opportunity.. [optional]  # noqa: E501
            type (str, none_type): The type of the opportunity. [optional]  # noqa: E501
            monetary_amount (float, none_type): The monetary value associated with the opportunity. [optional]  # noqa: E501
            currency (Currency): [optional]  # noqa: E501
            win_probability (float, none_type): The probability of winning the opportunity, expressed as a percentage.. [optional]  # noqa: E501
            expected_revenue (float, none_type): The expected revenue from the opportunity. [optional]  # noqa: E501
            close_date (date, none_type): The actual closing date for the opportunity. If close_date is null, the opportunity is not closed yet.. [optional]  # noqa: E501
            loss_reason_id (str, none_type): The unique identifier of the reason why the opportunity was lost.. [optional]  # noqa: E501
            loss_reason (str, none_type): The reason why the opportunity was lost.. [optional]  # noqa: E501
            won_reason_id (str, none_type): The unique identifier of the reason why the opportunity was won.. [optional]  # noqa: E501
            won_reason (str, none_type): The reason why the opportunity was won.. [optional]  # noqa: E501
            pipeline_id (str, none_type): The unique identifier of the pipeline associated with the opportunity. [optional]  # noqa: E501
            pipeline_stage_id (str, none_type): The unique identifier of the stage in the pipeline associated with the opportunity.. [optional]  # noqa: E501
            source_id (str, none_type): The unique identifier of the source of the opportunity.. [optional]  # noqa: E501
            lead_id (str, none_type): The unique identifier of the lead associated with the opportunity.. [optional]  # noqa: E501
            lead_source (str, none_type): The source of the lead associated with the opportunity.. [optional]  # noqa: E501
            contact_id (str, none_type): The unique identifier of the contact associated with the opportunity.. [optional]  # noqa: E501
            contact_ids ([str]): An array of unique identifiers of all contacts associated with the opportunity.. [optional]  # noqa: E501
            company_id (str, none_type): The unique identifier of the company associated with the opportunity.. [optional]  # noqa: E501
            company_name (str, none_type): The name of the company associated with the opportunity.. [optional]  # noqa: E501
            owner_id (str, none_type): The unique identifier of the user who owns the opportunity.. [optional]  # noqa: E501
            priority (str, none_type): The priority level of the opportunity.. [optional]  # noqa: E501
            status (str, none_type): The current status of the opportunity.. [optional]  # noqa: E501
            status_id (str, none_type): The unique identifier of the current status of the opportunity.. [optional]  # noqa: E501
            tags (Tags): [optional]  # noqa: E501
            interaction_count (float, none_type): The number of interactions with the opportunity.. [optional]  # noqa: E501
            custom_fields ([CustomField]): [optional]  # noqa: E501
            stage_last_changed_at (datetime, none_type): The date and time when the stage of the opportunity was last changed.. [optional]  # noqa: E501
            last_activity_at (str, none_type): The date and time of the last activity associated with the opportunity.. [optional]  # noqa: E501
            deleted (bool): Indicates whether the opportunity has been deleted.. [optional]  # noqa: E501
            date_stage_changed (datetime, none_type): The date and time when the stage of the opportunity was last changed.. [optional]  # noqa: E501
            date_last_contacted (datetime, none_type): The date and time when the opportunity was last contacted.. [optional]  # noqa: E501
            date_lead_created (datetime, none_type): The date and time when the lead associated with the opportunity was created.. [optional]  # noqa: E501
            custom_mappings ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): When custom mappings are configured on the resource, the result is included here.. [optional]  # noqa: E501
            updated_by (str, none_type): The unique identifier of the user who last updated the opportunity.. [optional]  # noqa: E501
            created_by (str, none_type): The unique identifier of the user who created the opportunity.. [optional]  # noqa: E501
            updated_at (datetime, none_type): The date and time when the opportunity was last updated.. [optional]  # noqa: E501
            created_at (datetime, none_type): The date and time when the opportunity was created.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.title = title
        self.primary_contact_id = primary_contact_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, title, primary_contact_id, *args, **kwargs):  # noqa: E501
        """Opportunity - a model defined in OpenAPI

        Args:
            title (str): The title or name of the opportunity.
            primary_contact_id (str, none_type): The unique identifier of the primary contact associated with the opportunity.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): A unique identifier for the opportunity.. [optional]  # noqa: E501
            description (str, none_type): A description of the opportunity.. [optional]  # noqa: E501
            type (str, none_type): The type of the opportunity. [optional]  # noqa: E501
            monetary_amount (float, none_type): The monetary value associated with the opportunity. [optional]  # noqa: E501
            currency (Currency): [optional]  # noqa: E501
            win_probability (float, none_type): The probability of winning the opportunity, expressed as a percentage.. [optional]  # noqa: E501
            expected_revenue (float, none_type): The expected revenue from the opportunity. [optional]  # noqa: E501
            close_date (date, none_type): The actual closing date for the opportunity. If close_date is null, the opportunity is not closed yet.. [optional]  # noqa: E501
            loss_reason_id (str, none_type): The unique identifier of the reason why the opportunity was lost.. [optional]  # noqa: E501
            loss_reason (str, none_type): The reason why the opportunity was lost.. [optional]  # noqa: E501
            won_reason_id (str, none_type): The unique identifier of the reason why the opportunity was won.. [optional]  # noqa: E501
            won_reason (str, none_type): The reason why the opportunity was won.. [optional]  # noqa: E501
            pipeline_id (str, none_type): The unique identifier of the pipeline associated with the opportunity. [optional]  # noqa: E501
            pipeline_stage_id (str, none_type): The unique identifier of the stage in the pipeline associated with the opportunity.. [optional]  # noqa: E501
            source_id (str, none_type): The unique identifier of the source of the opportunity.. [optional]  # noqa: E501
            lead_id (str, none_type): The unique identifier of the lead associated with the opportunity.. [optional]  # noqa: E501
            lead_source (str, none_type): The source of the lead associated with the opportunity.. [optional]  # noqa: E501
            contact_id (str, none_type): The unique identifier of the contact associated with the opportunity.. [optional]  # noqa: E501
            contact_ids ([str]): An array of unique identifiers of all contacts associated with the opportunity.. [optional]  # noqa: E501
            company_id (str, none_type): The unique identifier of the company associated with the opportunity.. [optional]  # noqa: E501
            company_name (str, none_type): The name of the company associated with the opportunity.. [optional]  # noqa: E501
            owner_id (str, none_type): The unique identifier of the user who owns the opportunity.. [optional]  # noqa: E501
            priority (str, none_type): The priority level of the opportunity.. [optional]  # noqa: E501
            status (str, none_type): The current status of the opportunity.. [optional]  # noqa: E501
            status_id (str, none_type): The unique identifier of the current status of the opportunity.. [optional]  # noqa: E501
            tags (Tags): [optional]  # noqa: E501
            interaction_count (float, none_type): The number of interactions with the opportunity.. [optional]  # noqa: E501
            custom_fields ([CustomField]): [optional]  # noqa: E501
            stage_last_changed_at (datetime, none_type): The date and time when the stage of the opportunity was last changed.. [optional]  # noqa: E501
            last_activity_at (str, none_type): The date and time of the last activity associated with the opportunity.. [optional]  # noqa: E501
            deleted (bool): Indicates whether the opportunity has been deleted.. [optional]  # noqa: E501
            date_stage_changed (datetime, none_type): The date and time when the stage of the opportunity was last changed.. [optional]  # noqa: E501
            date_last_contacted (datetime, none_type): The date and time when the opportunity was last contacted.. [optional]  # noqa: E501
            date_lead_created (datetime, none_type): The date and time when the lead associated with the opportunity was created.. [optional]  # noqa: E501
            custom_mappings ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): When custom mappings are configured on the resource, the result is included here.. [optional]  # noqa: E501
            updated_by (str, none_type): The unique identifier of the user who last updated the opportunity.. [optional]  # noqa: E501
            created_by (str, none_type): The unique identifier of the user who created the opportunity.. [optional]  # noqa: E501
            updated_at (datetime, none_type): The date and time when the opportunity was last updated.. [optional]  # noqa: E501
            created_at (datetime, none_type): The date and time when the opportunity was created.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.title = title
        self.primary_contact_id = primary_contact_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.connector_api import ConnectorApi  # noqa: E501


class TestConnectorApi(unittest.TestCase):
    """ConnectorApi unit test stubs"""

    def setUp(self):
        self.api = ConnectorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_resource_coverage_one(self):
        """Test case for api_resource_coverage_one

        Get API Resource Coverage  # noqa: E501
        """
        pass

    def test_api_resources_one(self):
        """Test case for api_resources_one

        Get API Resource  # noqa: E501
        """
        pass

    def test_apis_all(self):
        """Test case for apis_all

        List APIs  # noqa: E501
        """
        pass

    def test_apis_one(self):
        """Test case for apis_one

        Get API  # noqa: E501
        """
        pass

    def test_connector_docs_one(self):
        """Test case for connector_docs_one

        Get Connector Doc content  # noqa: E501
        """
        pass

    def test_connector_resources_one(self):
        """Test case for connector_resources_one

        Get Connector Resource  # noqa: E501
        """
        pass

    def test_connectors_all(self):
        """Test case for connectors_all

        List Connectors  # noqa: E501
        """
        pass

    def test_connectors_one(self):
        """Test case for connectors_one

        Get Connector  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.auth_type import AuthType
from apideck.model.connection_configuration import ConnectionConfiguration
from apideck.model.connection_state import ConnectionState
from apideck.model.custom_mapping import CustomMapping
from apideck.model.form_field import FormField
from apideck.model.integration_state import IntegrationState
from apideck.model.o_auth_grant_type import OAuthGrantType
from apideck.model.webhook_subscription import WebhookSubscription
globals()['AuthType'] = AuthType
globals()['ConnectionConfiguration'] = ConnectionConfiguration
globals()['ConnectionState'] = ConnectionState
globals()['CustomMapping'] = CustomMapping
globals()['FormField'] = FormField
globals()['IntegrationState'] = IntegrationState
globals()['OAuthGrantType'] = OAuthGrantType
globals()['WebhookSubscription'] = WebhookSubscription
from apideck.model.connection import Connection


class TestConnection(unittest.TestCase):
    """Connection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConnection(self):
        """Test Connection"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Connection()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
